Module: Sus::Fixtures::TemporaryDirectoryContext
- Defined in:
- lib/sus/fixtures/temporary_directory_context.rb
Overview
Provides a temporary directory context for tests that need isolated file system access.
Instance Attribute Summary collapse
-
#root ⇒ Object
readonly
Returns the value of attribute root.
- #The path to the temporary directory root.(pathtothetemporarydirectoryroot.) ⇒ Object readonly
Instance Method Summary collapse
-
#around(&block) ⇒ Object
Set up a temporary directory before the test and clean it up after.
Instance Attribute Details
#root ⇒ Object (readonly)
Returns the value of attribute root.
23 24 25 |
# File 'lib/sus/fixtures/temporary_directory_context.rb', line 23 def root @root end |
#The path to the temporary directory root.(pathtothetemporarydirectoryroot.) ⇒ Object (readonly)
23 |
# File 'lib/sus/fixtures/temporary_directory_context.rb', line 23 attr :root |